(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     22823,        606]
NotebookOptionsPosition[     20641,        560]
NotebookOutlinePosition[     21210,        579]
CellTagsIndexPosition[     21167,        576]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook provides a basic interface to ",
 ButtonBox["CDD",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://people.inf.ethz.ch/fukudak/cdd_home/"], None},
  ButtonNote->"https://people.inf.ethz.ch/fukudak/cdd_home/"],
 " for vertex enumeration (",
 StyleBox["cddHtoV", "Code"],
 ") and facet enumeration (",
 StyleBox["cddVtoH", "Code"],
 ")\n",
 StyleBox["\[Copyright] 2021 Matthew F. Pusey\nPermission is hereby granted, \
free of charge, to any person obtaining a copy of this software and \
associated documentation files (the \[OpenCurlyDoubleQuote]Software\
\[CloseCurlyDoubleQuote]), to deal in the Software without restriction, \
including without limitation the rights to use, copy, modify, merge, publish, \
distribute, sublicense, and/or sell copies of the Software, and to permit \
persons to whom the Software is furnished to do so, subject to the following \
conditions:\nThe above copyright notice and this permission notice shall be \
included in all copies or substantial portions of the Software.\nTHE SOFTWARE \
IS PROVIDED \[OpenCurlyDoubleQuote]AS IS\[CloseCurlyDoubleQuote], WITHOUT \
WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE \
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND \
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE \
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, \
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR \
THE USE OR OTHER DEALINGS IN THE SOFTWARE.",
  FontSize->8]
}], "Text",
 CellChangeTimes->{{3.837857015822462*^9, 3.837857090546006*^9}, {
  3.83785713708144*^9, 3.8378571627079773`*^9}, {3.8378572851225843`*^9, 
  3.8378572932346582`*^9}, {3.837857443204524*^9, 3.837857445076305*^9}, {
  3.837857967676592*^9, 3.837857967680051*^9}, {3.837858928380932*^9, 
  3.837858932444628*^9}, {3.837859001554365*^9, 3.8378590553160057`*^9}, {
  3.838190004212728*^9, 
  3.838190006252678*^9}},ExpressionUUID->"ce53f9fc-a8e6-4d7c-9ac5-\
cd6ea90a8dd7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cddcommand", "=", "\"\<cddexec --rep <\>\""}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "the", " ", "right", " ", "command", " ", "on", 
      " ", "Debian", " ", "10", " ", "with", " ", "libcdd"}], "-", 
     RowBox[{"tools", " ", "installed"}]}], ",", " ", 
    RowBox[{"change", " ", "for", " ", "other", " ", "platforms"}]}], " ", 
   "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"readHfile", "[", 
   RowBox[{"fn_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"result", ",", "linearities", ",", "numbers", ",", "linidx"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"result", "=", 
      RowBox[{"Import", "[", 
       RowBox[{"fn", ",", "\"\<Table\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"linearities", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{"result", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<linearity\>\"", ",", "___"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"numbers", "=", 
      RowBox[{"Map", "[", 
       RowBox[{"ToExpression", ",", 
        RowBox[{"result", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"result", ",", 
               RowBox[{"{", 
                RowBox[{"_", ",", "d", ",", "_"}], "}"}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", "1"}], ";;", 
           RowBox[{
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"result", ",", 
               RowBox[{"{", "\"\<end\>\"", "}"}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], "]"}], 
         "]"}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"linearities", "\[Equal]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "numbers"}], "}"}], ",", 
       RowBox[{
        RowBox[{"linidx", "=", 
         RowBox[{"linearities", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", 
            RowBox[{"3", ";;"}]}], "]"}], "]"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"numbers", "[", 
           RowBox[{"[", "linidx", "]"}], "]"}], ",", 
          RowBox[{"numbers", "[", 
           RowBox[{"[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"Length", "[", "numbers", "]"}], "]"}], ",", 
              "linidx"}], "]"}], "]"}], "]"}]}], "}"}]}]}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cddVtoH", "[", "vertices_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"out", ",", "infile"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"out", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"N", "[", "vertices", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"infile", "=", 
       RowBox[{"CreateTemporary", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Export", "[", 
       RowBox[{"infile", ",", 
        RowBox[{"Join", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "\"\<mtx\>\"", "}"}], ",", 
            RowBox[{"{", "\"\<V-representation\>\"", "}"}], ",", 
            RowBox[{"{", "\"\<begin\>\"", "}"}], ",", 
            RowBox[{"Join", "[", 
             RowBox[{
              RowBox[{"Dimensions", "[", "out", "]"}], ",", 
              RowBox[{"{", "\"\<real\>\"", "}"}]}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", "out", ",", "\[IndentingNewLine]", 
          RowBox[{"{", "\"\<end\>\"", "}"}]}], "]"}], ",", "\"\<Table\>\"", 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<FieldSeparators\>\"", "\[Rule]", "\"\< \>\""}], ",", 
          RowBox[{"\"\<LineSeparators\>\"", "\[Rule]", "\"\<\\n\>\""}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"readHfile", "[", 
       RowBox[{
        RowBox[{
        "\"\<!\>\"", "<>", "cddcommand", "<>", "\"\< \>\"", "<>", "infile"}], 
        ",", 
        RowBox[{"Length", "[", 
         RowBox[{"out", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"readVfile", "[", 
   RowBox[{"fn_", ",", "d_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "result", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"result", "=", 
      RowBox[{"Import", "[", 
       RowBox[{"fn", ",", "\"\<Table\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", 
      RowBox[{"ToExpression", ",", 
       RowBox[{
        RowBox[{"result", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"result", ",", 
               RowBox[{"{", 
                RowBox[{"_", ",", "d", ",", "_"}], "}"}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", "1"}], ";;", 
           RowBox[{
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"result", ",", 
               RowBox[{"{", "\"\<end\>\"", "}"}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], "]"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", 
          RowBox[{"2", ";;"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cddHtoV", "[", 
   RowBox[{"equality_", ",", "positive_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"out", ",", "infile"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"out", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Join", "[", 
        RowBox[{"equality", ",", "positive"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"infile", "=", 
      RowBox[{"CreateTemporary", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{"infile", ",", 
       RowBox[{"Join", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "\"\<mtx\>\"", "}"}], ",", 
           RowBox[{"{", "\"\<H-representation\>\"", "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"equality", "\[NotEqual]", 
              RowBox[{"{", "}"}]}], ",", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"\"\<linearity\>\"", ",", 
                 RowBox[{"Length", "[", "equality", "]"}]}], "}"}], ",", 
               RowBox[{"Range", "[", 
                RowBox[{"Length", "[", "equality", "]"}], "]"}]}], "]"}]}], 
            "]"}], ",", 
           RowBox[{"{", "\"\<begin\>\"", "}"}], ",", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"Dimensions", "[", "out", "]"}], ",", 
             RowBox[{"{", "\"\<real\>\"", "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", "out", ",", "\[IndentingNewLine]", 
         RowBox[{"{", "\"\<end\>\"", "}"}]}], "]"}], ",", "\"\<Table\>\"", 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<FieldSeparators\>\"", "\[Rule]", "\"\< \>\""}], ",", 
         RowBox[{"\"\<LineSeparators\>\"", "\[Rule]", "\"\<\\n\>\""}]}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"readVfile", "[", 
      RowBox[{
       RowBox[{
       "\"\<!\>\"", "<>", "cddcommand", "<>", "\"\< \>\"", "<>", "infile"}], 
       ",", 
       RowBox[{"Length", "[", 
        RowBox[{"out", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.5994091224518547`*^9, 3.599409122598588*^9}, {
   3.5995739311904097`*^9, 3.599573937350273*^9}, {3.599573975749234*^9, 
   3.599573989495689*^9}, 3.599574037133733*^9, {3.59957418758184*^9, 
   3.599574189181509*^9}, {3.600457461405867*^9, 3.600457505300515*^9}, {
   3.6004575480447483`*^9, 3.600457561052621*^9}, {3.600458345077721*^9, 
   3.600458448928589*^9}, {3.653145719620036*^9, 3.6531457460182533`*^9}, {
   3.6531463243867073`*^9, 3.6531463245208273`*^9}, {3.653147757695981*^9, 
   3.653147769868479*^9}, {3.65314780435607*^9, 3.653147828357499*^9}, {
   3.653148800404167*^9, 3.653148802619035*^9}, {3.6787240830988283`*^9, 
   3.678724098499441*^9}, {3.6787364934801197`*^9, 3.678736495926985*^9}, {
   3.6787365424388447`*^9, 3.678736542927417*^9}, {3.833628863572755*^9, 
   3.833628877608523*^9}, {3.833951321911419*^9, 3.833951344685433*^9}, {
   3.833951387229279*^9, 3.833951392667811*^9}, {3.833951425996271*^9, 
   3.833951453376493*^9}, {3.833952414762547*^9, 3.833952414928121*^9}, {
   3.833977900431312*^9, 3.83397793095951*^9}, {3.833977964012594*^9, 
   3.833977965687097*^9}, {3.8339780009143963`*^9, 3.8339780347453747`*^9}, {
   3.833978076581367*^9, 3.833978079444751*^9}, {3.833978109692288*^9, 
   3.833978110783678*^9}, {3.833978171176366*^9, 3.833978172102776*^9}, {
   3.8339782717312107`*^9, 3.833978295872203*^9}},
 CellLabel->
  "In[376]:=",ExpressionUUID->"7e64fbf2-4b1c-4102-af6f-d68fcc70f3fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Example", " ", "1"}], ":", " ", 
    RowBox[{
     RowBox[{"the", " ", "3"}], "-", 
     RowBox[{"dimensional", " ", "unit", " ", "cube"}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eqs1", ",", "ineqs1"}], "}"}], "=", 
   RowBox[{"cddVtoH", "[", GridBox[{
      {"0", "0", "0"},
      {"0", "0", "1"},
      {"0", "1", "0"},
      {"0", "1", "1"},
      {"1", "0", "0"},
      {"1", "0", "1"},
      {"1", "1", "0"},
      {"1", "1", "1"}
     }], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.625424703897326*^9, 3.625424781440422*^9}, {
  3.625424860886894*^9, 3.62542488157657*^9}, {3.625424973996763*^9, 
  3.6254249765187674`*^9}, {3.6531478535649776`*^9, 3.65314787989263*^9}},
 CellLabel->
  "In[381]:=",ExpressionUUID->"a55ed520-c392-480d-b4ac-adf3cd0f38f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8339787652753153`*^9, 3.833978767727508*^9}, 
   3.833978860946851*^9, 3.833978897527721*^9, 3.833979303488028*^9},
 CellLabel->
  "Out[381]=",ExpressionUUID->"960dc073-e477-4e64-8949-f481f86b1068"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"#", ".", 
       RowBox[{"{", 
        RowBox[{"1", ",", "x", ",", "y", ",", "z"}], "}"}]}], 
      "\[GreaterEqual]", "0"}], ")"}], "&"}], "/@", "ineqs1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.625424783416107*^9, 3.625424827373616*^9}, {
  3.625424959220595*^9, 3.6254249779722643`*^9}, {3.625425207332725*^9, 
  3.6254252203065042`*^9}},
 CellLabel->
  "In[333]:=",ExpressionUUID->"e7dea16e-1cd8-45b9-8f78-cfe13c1dd047"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"x", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"y", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"z", "\[LessEqual]", "1"}], ",", 
   RowBox[{"y", "\[LessEqual]", "1"}], ",", 
   RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.625424789615782*^9, 3.625424827695594*^9}, {
   3.625424963815036*^9, 3.625424986874826*^9}, 3.653146134351475*^9, 
   3.653150394972251*^9, 3.8339524195670424`*^9, 3.833977936202943*^9, 
   3.833978194758848*^9},
 CellLabel->
  "Out[333]=",ExpressionUUID->"acdc2543-4c29-4f79-8b18-c5ba3bfec615"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cddHtoV", "[", 
  RowBox[{"eqs1", ",", "ineqs1"}], "]"}]], "Input",
 CellChangeTimes->{{3.625424843577833*^9, 3.625424850406395*^9}, {
  3.625424980475827*^9, 3.6254249818355827`*^9}, {3.653150400086347*^9, 
  3.6531504003972607`*^9}},
 CellLabel->
  "In[334]:=",ExpressionUUID->"3a60270b-9266-4876-965d-b3f0fa51fad9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6254248507146273`*^9, {3.625424983593305*^9, 3.6254249883298397`*^9}, {
   3.6531478451916733`*^9, 3.653147846385195*^9}, {3.6531503962472067`*^9, 
   3.653150402262474*^9}, 3.833952420540365*^9, 3.8339779373530693`*^9, 
   3.833978195528489*^9},
 CellLabel->
  "Out[334]=",ExpressionUUID->"0da10d1e-2615-40fb-b795-f753441e0ffd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Example", " ", "2"}], ":", " ", 
    RowBox[{"binary", " ", "probability", " ", "distributions"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eqs2", ",", "ineqs2"}], "}"}], "=", 
   RowBox[{"cddVtoH", "[", GridBox[{
      {"1", "0"},
      {"0", "1"}
     }], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.625424885303565*^9, 3.625424913589922*^9}, {
  3.62542500383604*^9, 3.6254250044917183`*^9}, {3.65315040470977*^9, 
  3.653150404981288*^9}},
 CellLabel->
  "In[335]:=",ExpressionUUID->"fafddae6-256a-4799-aacd-146f7e5212d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.625424913791391*^9, {3.62542499653483*^9, 3.6254250052772007`*^9}, 
   3.653150405700293*^9, 3.833952422295402*^9, 3.833977938348133*^9, 
   3.833978196697948*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"62170fe3-7380-41a8-83b7-ce8eff1f9226"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"#", ".", 
       RowBox[{"{", 
        RowBox[{"1", ",", "p0", ",", "p1"}], "}"}]}], "\[Equal]", "0"}], 
     ")"}], "&"}], "/@", "eqs2"}], "]"}]], "Input",
 CellChangeTimes->{{3.625424939881021*^9, 3.6254249465494423`*^9}, 
   3.625425001126145*^9, 3.6254250961735687`*^9},
 CellLabel->
  "In[336]:=",ExpressionUUID->"35794d8f-6369-4cdb-96d7-154aaed2ec4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p0", "+", "p1"}], "\[Equal]", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.625424947295957*^9, {3.625424997677985*^9, 3.625425006710949*^9}, 
   3.62542509662253*^9, 3.653150406949059*^9, 3.833952423222912*^9, 
   3.833978197507996*^9},
 CellLabel->
  "Out[336]=",ExpressionUUID->"d7c38b88-7035-47e7-8348-1f68eba7f17d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"#", ".", 
       RowBox[{"{", 
        RowBox[{"1", ",", "p0", ",", "p1"}], "}"}]}], "\[GreaterEqual]", 
      "0"}], ")"}], "&"}], "/@", "ineqs2"}], "]"}]], "Input",
 CellChangeTimes->{{3.625424921927205*^9, 3.625424955197953*^9}, 
   3.625425002419997*^9},
 CellLabel->
  "In[337]:=",ExpressionUUID->"96c1a75c-96ce-465d-a011-a666941c6f6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p0", "\[LessEqual]", "1"}], ",", 
   RowBox[{"p0", "\[GreaterEqual]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.625424918653819*^9, 3.6254249244795437`*^9}, 
   3.625424955539126*^9, {3.625424998963628*^9, 3.625425008437001*^9}, 
   3.653150408091688*^9, 3.833952424087111*^9, 3.833978198197937*^9},
 CellLabel->
  "Out[337]=",ExpressionUUID->"d0082feb-38cb-4192-a10c-a6da060e415f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cddHtoV", "[", 
  RowBox[{"eqs2", ",", "ineqs2"}], "]"}]], "Input",
 CellChangeTimes->{{3.6254250141230783`*^9, 3.625425016011053*^9}, {
  3.653150410982313*^9, 3.6531504112452497`*^9}},
 CellLabel->
  "In[338]:=",ExpressionUUID->"5118a167-ce0c-45c9-a091-abb565e544fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.625425016782028*^9, {3.653150409074279*^9, 3.653150411985704*^9}, 
   3.83395242508737*^9, 3.833978199713986*^9},
 CellLabel->
  "Out[338]=",ExpressionUUID->"c9ae5832-13ce-4b8f-b13e-e29a93a5ba6a"]
}, Open  ]]
},
WindowSize->{719.25, 795.75},
WindowMargins->{{Automatic, 0}, {0., 14.25}},
WindowStatusArea->"cdd_interface.nb last backed up to cdd_interface.nb~ on \
Thu 28 Jul 2016 at 7:14:56 PM",
SpellingDictionaries->{"CorrectWords"->{"blicense", "sublicense"}},
FrontEndVersion->"12.1 for Linux x86 (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"75ae1348-1a83-4297-acab-7aec9288bb74"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 2068, 37, 170, "Text",ExpressionUUID->"ce53f9fc-a8e6-4d7c-9ac5-cd6ea90a8dd7"],
Cell[2629, 59, 9760, 240, 731, "Input",ExpressionUUID->"7e64fbf2-4b1c-4102-af6f-d68fcc70f3fc"],
Cell[CellGroupData[{
Cell[12414, 303, 867, 26, 181, "Input",ExpressionUUID->"a55ed520-c392-480d-b4ac-adf3cd0f38f2"],
Cell[13284, 331, 912, 25, 55, "Output",ExpressionUUID->"960dc073-e477-4e64-8949-f481f86b1068"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14233, 361, 539, 15, 29, "Input",ExpressionUUID->"e7dea16e-1cd8-45b9-8f78-cfe13c1dd047"],
Cell[14775, 378, 651, 14, 33, "Output",ExpressionUUID->"acdc2543-4c29-4f79-8b18-c5ba3bfec615"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15463, 397, 342, 7, 29, "Input",ExpressionUUID->"3a60270b-9266-4876-965d-b3f0fa51fad9"],
Cell[15808, 406, 959, 25, 55, "Output",ExpressionUUID->"0da10d1e-2615-40fb-b795-f753441e0ffd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16804, 436, 628, 18, 65, "Input",ExpressionUUID->"fafddae6-256a-4799-aacd-146f7e5212d4"],
Cell[17435, 456, 649, 19, 33, "Output",ExpressionUUID->"62170fe3-7380-41a8-83b7-ce8eff1f9226"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18121, 480, 468, 13, 29, "Input",ExpressionUUID->"35794d8f-6369-4cdb-96d7-154aaed2ec4b"],
Cell[18592, 495, 375, 9, 33, "Output",ExpressionUUID->"d7c38b88-7035-47e7-8348-1f68eba7f17d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19004, 509, 452, 13, 29, "Input",ExpressionUUID->"96c1a75c-96ce-465d-a011-a666941c6f6f"],
Cell[19459, 524, 441, 9, 33, "Output",ExpressionUUID->"d0082feb-38cb-4192-a10c-a6da060e415f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19937, 538, 293, 6, 29, "Input",ExpressionUUID->"5118a167-ce0c-45c9-a091-abb565e544fd"],
Cell[20233, 546, 392, 11, 33, "Output",ExpressionUUID->"c9ae5832-13ce-4b8f-b13e-e29a93a5ba6a"]
}, Open  ]]
}
]
*)

